# Field Updates

## Electric Field Updates
::: fdtdx.fdtd.update.update_E
::: fdtdx.fdtd.update.update_E_reverse

## Magnetic Field Updates  
::: fdtdx.fdtd.update.update_H
::: fdtdx.fdtd.update.update_H_reverse
